---
name: Device support
about: Request support for a new device type
title: ''
labels: device support'
assignees: ''

---

# Description of the device

<!-- A clear and concise description of what the feature is. -->


# Justification

<!-- Why is this hardware needed? What additional capabilities will this -->
<!-- enable? -->


# Special Requirements

<!-- Are there any unique requirements that this hardware needs? By default -->
<!-- all devices will be ophyd-async. -->


# EPICS Module Documentation

<!-- Which PVs are available in the EPICS module? This can be a link to the -->
<!-- EPICS module documentation, otherwise please provide the list of PVs, -->
<!-- data types, and requested names. -->


# Existing Implementation

<!-- Is there an existing implementation in either Ophyd or ophyd-async that can be consulted? -->


# Additional context

<!-- Any other useful information? -->
